from setuptools import setup

setup(
    name='test14416148',
    packages=['test14416148'],
    version='1.0',
    license='MIT',
    description='test',
    author='test',
    keywords=['test'],
    install_requires=[''],
    classifiers=['Development Status :: 5 - Production/Stable', 'Intended Audience :: Developers', 'Topic :: Software Development :: Libraries :: Python Modules', 'License :: OSI Approved :: MIT License', 'Programming Language :: Python :: 3.10']
)
